@@ -2,8 +2,8 @@ from pequod_cli.service import CoreService
 
 
 class CoreManager(CoreService):
-    def __init__(self, endpoints, credentials):
-        super().__init__(endpoints, 'core-manager', credentials)
+    def __init__(self, endpoints, credentials, cacert):
+        super().__init__(endpoints, 'core-manager', credentials, cacert)
 
     def get_zones(self):
         data = self.get('/zones')
